@@ -9,4 +9,4 @@ def scopes(scope_int):
     Wrapper around :attr:`provider.scope.names` to turn an int into a list
     of scope names in templates.
     """
-    return scope.names(scope_int)
+    return scope.to_names(scope_int)
