@@ -6,6 +6,7 @@ from django.views.generic.base import TemplateView, View
 from provider import constants
 import json
 import urlparse
+from provider import scope
 
 class OAuthError(Exception):
     """
@@ -255,10 +256,16 @@ class Authorize(OAuthView, Mixin):
             data)
 
         if not authorization_form.is_bound:
-            return self.render_to_response({'form': authorization_form})
+            return self.render_to_response({
+                'client': client,
+                'form': authorization_form,
+                'oauth_data': data, })
         
         if not authorization_form.is_valid():
-            return self.render_to_response({'form': authorization_form})
+            return self.render_to_response({
+                'client': client,
+                'form': authorization_form,
+                'oauth_data': data, })
         
         code = self.save_authorization(request, client, authorization_form, data)
 
@@ -287,9 +294,7 @@ class Redirect(OAuthView, Mixin):
         error = self.get_data(request, "error")
         client = self.get_data(request, "client")
 
-        self.clear_data(request)
-
-        redirect_uri = data.get('redirect_uri', client.redirect_uri)
+        redirect_uri = data.get('redirect_uri', None) or client.redirect_uri
 
         parsed = urlparse.urlparse(redirect_uri)
 
@@ -308,6 +313,8 @@ class Redirect(OAuthView, Mixin):
         parsed = parsed[:4] + (query.urlencode(), '')
 
         redirect_uri = urlparse.ParseResult(*parsed).geturl()
+
+        self.clear_data(request)
                 
         return HttpResponseRedirect(redirect_uri)        
 
@@ -432,7 +439,7 @@ class AccessToken(OAuthView, Mixin):
                 'access_token': access_token.token,
                 'expires_in': access_token.get_expire_delta(),
                 'refresh_token': access_token.refresh_token.token,
-                'scope': access_token.scope
+                'scope': ' '.join(scope.names(access_token.scope)),
             }), mimetype='application/json'
         )
     
